==> pegasus-support-1.6.22-sources.jar: com/thebeastshop/support/vo/exchange/ExchangeCouponGoods.java <==
package com.thebeastshop.support.vo.exchange;

import java.util.Date;

/**
 * @author feilong.gao
 * @Date 2018/5/23 17:06.
 * @Description
 */
public class ExchangeCouponGoods extends ExchangeGoods {

    private String title;              //标题
    private String description;        //详细说明
    private String thresholdDesc;      // 门槛描述
    private String note;               // 备注
    private String logo;               // logo图片地址
    private Date startTime;            // 开始时间
    private Date expireTime;           // 过期时间
    private Integer days;              // 领取后N天

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getThresholdDesc() {
        return thresholdDesc;
    }

    public void setThresholdDesc(String thresholdDesc) {
        this.thresholdDesc = thresholdDesc;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(Date expireTime) {
        this.expireTime = expireTime;
    }

    public Integer getDays() {
        return days;
    }

    public void setDays(Integer days) {
        this.days = days;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("ExchangeCouponGoods{");
        sb.append("title='").append(title).append('\'');
        sb.append(", description='").append(description).append('\'');
        sb.append(", thresholdDesc='").append(thresholdDesc).append('\'');
        sb.append(", note='").append(note).append('\'');
        sb.append(", logo='").append(logo).append('\'');
        sb.append(", startTime=").append(startTime);
        sb.append(", expireTime=").append(expireTime);
        sb.append(", days=").append(days);
        sb.append('}');
        return sb.toString();
    }
}

==> pegasus-support-1.8.2-sources.jar: com/thebeastshop/support/vo/exchange/ExchangeCouponGoods.java <==
package com.thebeastshop.support.vo.exchange;

import com.thebeastshop.support.enums.exchange.ExchangeGoodsClassify;

import java.util.Date;

/**
 * @author feilong.gao
 * @Date 2018/5/23 17:06.
 * @Description
 */
public class ExchangeCouponGoods extends ExchangeGoods {

    private String title;              //标题
    private String description;        //详细说明
    private String thresholdDesc;      // 门槛描述
    private String note;               // 备注
    private String logo;               // logo图片地址
    private Date startTime;            // 开始时间
    private Date expireTime;           // 过期时间
    private Integer days;              // 领取后N天

    public ExchangeCouponGoods() {
        classify = ExchangeGoodsClassify.COUPON;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getThresholdDesc() {
        return thresholdDesc;
    }

    public void setThresholdDesc(String thresholdDesc) {
        this.thresholdDesc = thresholdDesc;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(Date expireTime) {
        this.expireTime = expireTime;
    }

    public Integer getDays() {
        return days;
    }

    public void setDays(Integer days) {
        this.days = days;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("ExchangeCouponGoods{");
        sb.append("title='").append(title).append('\'');
        sb.append(", description='").append(description).append('\'');
        sb.append(", thresholdDesc='").append(thresholdDesc).append('\'');
        sb.append(", note='").append(note).append('\'');
        sb.append(", logo='").append(logo).append('\'');
        sb.append(", startTime=").append(startTime);
        sb.append(", expireTime=").append(expireTime);
        sb.append(", days=").append(days);
        sb.append('}');
        return sb.toString();
    }
}
